package jp.metanest.tcu;
import junit.framework.TestCase;

public class TCUTest extends TestCase {
	public TCUTest(final String name) {
		super(name);
	}

	public void testJISX0208() {
		final Converter converter = new Converter();

		final JISX0208_1990 j_1_1 = new JISX0208_1990(1, 1);
		final TRONCode j_1_1_tc = converter.to_tc(j_1_1);
		final String j_1_1_tc_s = j_1_1_tc.toString();
		assertEquals("1-2121", j_1_1_tc_s);

		final JISX0208_1990 j_84_6 = new JISX0208_1990(84, 6);
		final TRONCode j_84_6_tc = converter.to_tc(j_84_6);
		final String j_84_6_tc_s = j_84_6_tc.toString();
		assertEquals("1-7426", j_84_6_tc_s);

		final JISX0208_1990 j_25_29 = new JISX0208_1990(25, 29);
		final TRONCode j_25_29_tc = converter.to_tc(j_25_29);
		final String j_25_29_tc_s = j_25_29_tc.toString();
		assertEquals("1-393D", j_25_29_tc_s);

		final JISX0208_1990 j_71_78 = new JISX0208_1990(71, 78);
		final TRONCode j_71_78_tc = converter.to_tc(j_71_78);
		final String j_71_78_tc_s = j_71_78_tc.toString();
		assertEquals("1-676E", j_71_78_tc_s);

		final JISX0208_1990 j_54_24 = new JISX0208_1990(54, 24);
		final TRONCode j_54_24_tc = converter.to_tc(j_54_24);
		final String j_54_24_tc_s = j_54_24_tc.toString();
		assertEquals("1-5638", j_54_24_tc_s);

		final JISX0208_1990 j_48_79 = new JISX0208_1990(48, 79);
		final TRONCode j_48_79_tc = converter.to_tc(j_48_79);
		final String j_48_79_tc_s = j_48_79_tc.toString();
		assertEquals("1-506F", j_48_79_tc_s);
	}

	public void testJISX0213() {
		final Converter converter = new Converter();

		/* face 1 (3rd level) */

		final JISX0213_2000 j34_1_2_15 = new JISX0213_2000(1, 2, 15);
		final TRONCode j34_1_2_15_tc = converter.to_tc(j34_1_2_15);
		final String j34_1_2_15_tc_s = j34_1_2_15_tc.toString();
		assertEquals("1-222F", j34_1_2_15_tc_s);

		final JISX0213_2000 j34_1_15_93 = new JISX0213_2000(1, 15, 93);
		final TRONCode j34_1_15_93_tc = converter.to_tc(j34_1_15_93);
		final String j34_1_15_93_tc_s = j34_1_15_93_tc.toString();
		assertEquals("1-2F7D", j34_1_15_93_tc_s);

		final JISX0213_2000 j34_1_47_53 = new JISX0213_2000(1, 47, 53);
		final TRONCode j34_1_47_53_tc = converter.to_tc(j34_1_47_53);
		final String j34_1_47_53_tc_s = j34_1_47_53_tc.toString();
		assertEquals("1-4F55", j34_1_47_53_tc_s);

		final JISX0213_2000 j34_1_47_93 = new JISX0213_2000(1, 47, 93);
		final TRONCode j34_1_47_93_tc = converter.to_tc(j34_1_47_93);
		final String j34_1_47_93_tc_s = j34_1_47_93_tc.toString();
		assertEquals("1-4F7D", j34_1_47_93_tc_s);

		final JISX0213_2000 j34_1_84_8 = new JISX0213_2000(1, 84, 8);
		final TRONCode j34_1_84_8_tc = converter.to_tc(j34_1_84_8);
		final String j34_1_84_8_tc_s = j34_1_84_8_tc.toString();
		assertEquals("1-7428", j34_1_84_8_tc_s);

		final JISX0213_2000 j34_1_94_89 = new JISX0213_2000(1, 94, 89);
		final TRONCode j34_1_94_89_tc = converter.to_tc(j34_1_94_89);
		final String j34_1_94_89_tc_s = j34_1_94_89_tc.toString();
		assertEquals("1-7E79", j34_1_94_89_tc_s);

		/* face 2 (4th level) */

		final JISX0213_2000 j34_2_1_45 = new JISX0213_2000(2, 1, 45);
		final TRONCode j34_2_1_45_tc = converter.to_tc(j34_2_1_45);
		final String j34_2_1_45_tc_s = j34_2_1_45_tc.toString();
		assertEquals("1-874D", j34_2_1_45_tc_s);

		final JISX0213_2000 j34_2_3_62 = new JISX0213_2000(2, 3, 62);
		final TRONCode j34_2_3_62_tc = converter.to_tc(j34_2_3_62);
		final String j34_2_3_62_tc_s = j34_2_3_62_tc.toString();
		assertEquals("1-885E", j34_2_3_62_tc_s);

		final JISX0213_2000 j34_2_4_18 = new JISX0213_2000(2, 4, 18);
		final TRONCode j34_2_4_18_tc = converter.to_tc(j34_2_4_18);
		final String j34_2_4_18_tc_s = j34_2_4_18_tc.toString();
		assertEquals("1-8932", j34_2_4_18_tc_s);

		final JISX0213_2000 j34_2_5_80 = new JISX0213_2000(2, 5, 80);
		final TRONCode j34_2_5_80_tc = converter.to_tc(j34_2_5_80);
		final String j34_2_5_80_tc_s = j34_2_5_80_tc.toString();
		assertEquals("1-8A70", j34_2_5_80_tc_s);

		final JISX0213_2000 j34_2_8_23 = new JISX0213_2000(2, 8, 23);
		final TRONCode j34_2_8_23_tc = converter.to_tc(j34_2_8_23);
		final String j34_2_8_23_tc_s = j34_2_8_23_tc.toString();
		assertEquals("1-8B37", j34_2_8_23_tc_s);

		final JISX0213_2000 j34_2_12_11 = new JISX0213_2000(2, 12, 11);
		final TRONCode j34_2_12_11_tc = converter.to_tc(j34_2_12_11);
		final String j34_2_12_11_tc_s = j34_2_12_11_tc.toString();
		assertEquals("1-8C2B", j34_2_12_11_tc_s);

		final JISX0213_2000 j34_2_13_91 = new JISX0213_2000(2, 13, 91);
		final TRONCode j34_2_13_91_tc = converter.to_tc(j34_2_13_91);
		final String j34_2_13_91_tc_s = j34_2_13_91_tc.toString();
		assertEquals("1-8D7B", j34_2_13_91_tc_s);

		final JISX0213_2000 j34_2_14_23 = new JISX0213_2000(2, 14, 23);
		final TRONCode j34_2_14_23_tc = converter.to_tc(j34_2_14_23);
		final String j34_2_14_23_tc_s = j34_2_14_23_tc.toString();
		assertEquals("1-8E37", j34_2_14_23_tc_s);

		final JISX0213_2000 j34_2_15_21 = new JISX0213_2000(2, 15, 21);
		final TRONCode j34_2_15_21_tc = converter.to_tc(j34_2_15_21);
		final String j34_2_15_21_tc_s = j34_2_15_21_tc.toString();
		assertEquals("1-8F35", j34_2_15_21_tc_s);

		final JISX0213_2000 j34_2_78_43 = new JISX0213_2000(2, 78, 43);
		final TRONCode j34_2_78_43_tc = converter.to_tc(j34_2_78_43);
		final String j34_2_78_43_tc_s = j34_2_78_43_tc.toString();
		assertEquals("1-904B", j34_2_78_43_tc_s);

		final JISX0213_2000 j34_2_94_66 = new JISX0213_2000(2, 94, 66);
		final TRONCode j34_2_94_66_tc = converter.to_tc(j34_2_94_66);
		final String j34_2_94_66_tc_s = j34_2_94_66_tc.toString();
		assertEquals("1-A062", j34_2_94_66_tc_s);

		final JISX0213_2000 j34_2_86_56 = new JISX0213_2000(2, 86, 56);
		final TRONCode j34_2_86_56_tc = converter.to_tc(j34_2_86_56);
		final String j34_2_86_56_tc_s = j34_2_86_56_tc.toString();
		assertEquals("1-9858", j34_2_86_56_tc_s);

		final JISX0213_2000 j34_2_80_8 = new JISX0213_2000(2, 80, 8);
		final TRONCode j34_2_80_8_tc = converter.to_tc(j34_2_80_8);
		final String j34_2_80_8_tc_s = j34_2_80_8_tc.toString();
		assertEquals("1-9228", j34_2_80_8_tc_s);
		/*
		 * memo
		 * 1$B6h(B - 87
		 * 3$B!A(B5$B6h(B - 88$B!A(B8A
		 * 8$B6h(B - 8B
		 * 12$B!A(B15$B6h(B - 8C$B!A(B8F
		 * 78$B!A(B94$B6h(B - 90$B!A(BA0
		 */
	}

	public void testJISX0212() {
		final Converter converter = new Converter();

		final JISX0212_1990 jh_2_15 = new JISX0212_1990(2, 15);
		final TRONCode jh_2_15_tc = converter.to_tc(jh_2_15);
		final String jh_2_15_tc_s = jh_2_15_tc.toString();
		assertEquals("1-A22F", jh_2_15_tc_s);

		final JISX0212_1990 jh_11_87 = new JISX0212_1990(11, 87);
		final TRONCode jh_11_87_tc = converter.to_tc(jh_11_87);
		final String jh_11_87_tc_s = jh_11_87_tc.toString();
		assertEquals("1-AB77", jh_11_87_tc_s);

		final JISX0212_1990 jh_44_61 = new JISX0212_1990(44, 61);
		final TRONCode jh_44_61_tc = converter.to_tc(jh_44_61);
		final String jh_44_61_tc_s = jh_44_61_tc.toString();
		assertEquals("1-CC5D", jh_44_61_tc_s);

		final JISX0212_1990 jh_62_5 = new JISX0212_1990(62, 5);
		final TRONCode jh_62_5_tc = converter.to_tc(jh_62_5);
		final String jh_62_5_tc_s = jh_62_5_tc.toString();
		assertEquals("1-DE25", jh_62_5_tc_s);

		final JISX0212_1990 jh_77_67 = new JISX0212_1990(77, 67);
		final TRONCode jh_77_67_tc = converter.to_tc(jh_77_67);
		final String jh_77_67_tc_s = jh_77_67_tc.toString();
		assertEquals("1-ED63", jh_77_67_tc_s);
	}

	public void testGB2312() {
		final Converter converter = new Converter();

		final GB2312_1980 c_1_1 = new GB2312_1980(1, 1);
		final TRONCode c_1_1_tc = converter.to_tc(c_1_1);
		final String c_1_1_tc_s = c_1_1_tc.toString();
		assertEquals("1-2180", c_1_1_tc_s);

		final GB2312_1980 c_1_94 = new GB2312_1980(1, 94);
		final TRONCode c_1_94_tc = converter.to_tc(c_1_94);
		final String c_1_94_tc_s = c_1_94_tc.toString();
		assertEquals("1-21DD", c_1_94_tc_s);

		final GB2312_1980 c_2_1 = new GB2312_1980(2, 1);
		final TRONCode c_2_1_tc = converter.to_tc(c_2_1);
		final String c_2_1_tc_s = c_2_1_tc.toString();
		assertEquals("1-21DE", c_2_1_tc_s);

		final GB2312_1980 c_2_32 = new GB2312_1980(2, 32);
		final TRONCode c_2_32_tc = converter.to_tc(c_2_32);
		final String c_2_32_tc_s = c_2_32_tc.toString();
		assertEquals("1-21FD", c_2_32_tc_s);

		final GB2312_1980 c_2_33 = new GB2312_1980(2, 33);
		final TRONCode c_2_33_tc = converter.to_tc(c_2_33);
		final String c_2_33_tc_s = c_2_33_tc.toString();
		assertEquals("1-2280", c_2_33_tc_s);

		final GB2312_1980 c_87_94 = new GB2312_1980(87, 94);
		final TRONCode c_87_94_tc = converter.to_tc(c_87_94);
		final String c_87_94_tc_s = c_87_94_tc.toString();
		assertEquals("1-61F1", c_87_94_tc_s);

		final GB2312_1980 c_18_67 = new GB2312_1980(18, 67);
		final TRONCode c_18_67_tc = converter.to_tc(c_18_67);
		final String c_18_67_tc_s = c_18_67_tc.toString();
		assertEquals("1-2E9A", c_18_67_tc_s);

		final GB2312_1980 c_49_11 = new GB2312_1980(49, 11);
		final TRONCode c_49_11_tc = converter.to_tc(c_49_11);
		final String c_49_11_tc_s = c_49_11_tc.toString();
		assertEquals("1-44F0", c_49_11_tc_s);
	}

	public void testKSX1001() {
		final Converter converter = new Converter();

		final KSX1001_1997 k_1_1 = new KSX1001_1997(1, 1);
		final TRONCode k_1_1_tc = converter.to_tc(k_1_1);
		final String k_1_1_tc_s = k_1_1_tc.toString();
		assertEquals("1-B780", k_1_1_tc_s);

		final KSX1001_1997 k_1_94 = new KSX1001_1997(1, 94);
		final TRONCode k_1_94_tc = converter.to_tc(k_1_94);
		final String k_1_94_tc_s = k_1_94_tc.toString();
		assertEquals("1-B7DD", k_1_94_tc_s);

		final KSX1001_1997 k_2_1 = new KSX1001_1997(2, 1);
		final TRONCode k_2_1_tc = converter.to_tc(k_2_1);
		final String k_2_1_tc_s = k_2_1_tc.toString();
		assertEquals("1-B7DE", k_2_1_tc_s);

		final KSX1001_1997 k_2_32 = new KSX1001_1997(2, 32);
		final TRONCode k_2_32_tc = converter.to_tc(k_2_32);
		final String k_2_32_tc_s = k_2_32_tc.toString();
		assertEquals("1-B7FD", k_2_32_tc_s);

		final KSX1001_1997 k_2_33 = new KSX1001_1997(2, 33);
		final TRONCode k_2_33_tc = converter.to_tc(k_2_33);
		final String k_2_33_tc_s = k_2_33_tc.toString();
		assertEquals("1-B880", k_2_33_tc_s);

		final KSX1001_1997 k_93_94 = new KSX1001_1997(93, 94);
		final TRONCode k_93_94_tc = converter.to_tc(k_93_94);
		final String k_93_94_tc_s = k_93_94_tc.toString();
		assertEquals("1-FCAF", k_93_94_tc_s);

		final KSX1001_1997 k_27_3 = new KSX1001_1997(27, 3);
		final TRONCode k_27_3_tc = converter.to_tc(k_27_3);
		final String k_27_3_tc_s = k_27_3_tc.toString();
		assertEquals("1-CAB4", k_27_3_tc_s);

		final KSX1001_1997 k_67_69 = new KSX1001_1997(67, 69);
		final TRONCode k_67_69_tc = converter.to_tc(k_67_69);
		final String k_67_69_tc_s = k_67_69_tc.toString();
		assertEquals("1-E8E2", k_67_69_tc_s);
	}

	public void testGT() {
		final Converter converter = new Converter();

		final GT gt_1 = new GT(1);
		final TRONCode gt_1_tc = converter.to_tc(gt_1);
		final String gt_1_tc_s = gt_1_tc.toString();
		assertEquals("2-2121", gt_1_tc_s);

		final GT gt_15725 = new GT(15725);
		final TRONCode gt_15725_tc = converter.to_tc(gt_15725);
		final String gt_15725_tc_s = gt_15725_tc.toString();
		assertEquals("2-C93B", gt_15725_tc_s);  // B Zone

		final GT gt_33098 = new GT(33098);
		final TRONCode gt_33098_tc = converter.to_tc(gt_33098);
		final String gt_33098_tc_s = gt_33098_tc.toString();
		assertEquals("2-84C5", gt_33098_tc_s);  // D Zone

		final GT gt_51140 = new GT(51140);
		final TRONCode gt_51140_tc = converter.to_tc(gt_51140);
		final String gt_51140_tc_s = gt_51140_tc.toString();
		assertEquals("3-3E2E", gt_51140_tc_s);  // A Zone

		final GT gt_24400 = new GT(24400);
		final TRONCode gt_24400_tc = converter.to_tc(gt_24400);
		final String gt_24400_tc_s = gt_24400_tc.toString();
		assertEquals("2-3EC1", gt_24400_tc_s);  // C Zone
	}

	public void testCNS() {
		final Converter converter = new Converter();

		final CNS11643_1992 c_1_1_1 = new CNS11643_1992(1, 1, 1);
		final TRONCode c_1_1_1_tc = converter.to_tc(c_1_1_1);
		final String c_1_1_1_tc_s = c_1_1_1_tc.toString();
		assertEquals("6-2121", c_1_1_1_tc_s);

		final CNS11643_1992 c_1_94_94 = new CNS11643_1992(1, 94, 94);
		final TRONCode c_1_94_94_tc = converter.to_tc(c_1_94_94);
		final String c_1_94_94_tc_s = c_1_94_94_tc.toString();
		assertEquals("6-7E7E", c_1_94_94_tc_s);

		final CNS11643_1992 c_2_1_1 = new CNS11643_1992(2, 1, 1);
		final TRONCode c_2_1_1_tc = converter.to_tc(c_2_1_1);
		final String c_2_1_1_tc_s = c_2_1_1_tc.toString();
		assertEquals("6-8021", c_2_1_1_tc_s);

		final CNS11643_1992 c_2_94_94 = new CNS11643_1992(2, 94, 94);
		final TRONCode c_2_94_94_tc = converter.to_tc(c_2_94_94);
		final String c_2_94_94_tc_s = c_2_94_94_tc.toString();
		assertEquals("6-DD7E", c_2_94_94_tc_s);

		final CNS11643_1992 c_3_1_1 = new CNS11643_1992(3, 1, 1);
		final TRONCode c_3_1_1_tc = converter.to_tc(c_3_1_1);
		final String c_3_1_1_tc_s = c_3_1_1_tc.toString();
		assertEquals("6-DE21", c_3_1_1_tc_s);

		final CNS11643_1992 c_3_32_94 = new CNS11643_1992(3, 32, 94);
		final TRONCode c_3_32_94_tc = converter.to_tc(c_3_32_94);
		final String c_3_32_94_tc_s = c_3_32_94_tc.toString();
		assertEquals("6-FD7E", c_3_32_94_tc_s);

		final CNS11643_1992 c_3_33_1 = new CNS11643_1992(3, 33, 1);
		final TRONCode c_3_33_1_tc = converter.to_tc(c_3_33_1);
		final String c_3_33_1_tc_s = c_3_33_1_tc.toString();
		assertEquals("6-2180", c_3_33_1_tc_s);

		final CNS11643_1992 c_3_94_94 = new CNS11643_1992(3, 94, 94);
		final TRONCode c_3_94_94_tc = converter.to_tc(c_3_94_94);
		final String c_3_94_94_tc_s = c_3_94_94_tc.toString();
		assertEquals("6-4F9F", c_3_94_94_tc_s);

		final CNS11643_1992 c_4_1_1 = new CNS11643_1992(4, 1, 1);
		final TRONCode c_4_1_1_tc = converter.to_tc(c_4_1_1);
		final String c_4_1_1_tc_s = c_4_1_1_tc.toString();
		assertEquals("6-5080", c_4_1_1_tc_s);

		final CNS11643_1992 c_4_63_94 = new CNS11643_1992(4, 63, 94);
		final TRONCode c_4_63_94_tc = converter.to_tc(c_4_63_94);
		final String c_4_63_94_tc_s = c_4_63_94_tc.toString();
		assertEquals("6-7EFD", c_4_63_94_tc_s);

		final CNS11643_1992 c_4_64_1 = new CNS11643_1992(4, 64, 1);
		final TRONCode c_4_64_1_tc = converter.to_tc(c_4_64_1);
		final String c_4_64_1_tc_s = c_4_64_1_tc.toString();
		assertEquals("6-8080", c_4_64_1_tc_s);

		final CNS11643_1992 c_4_94_94 = new CNS11643_1992(4, 94, 94);
		final TRONCode c_4_94_94_tc = converter.to_tc(c_4_94_94);
		final String c_4_94_94_tc_s = c_4_94_94_tc.toString();
		assertEquals("6-978F", c_4_94_94_tc_s);

		final CNS11643_1992 c_5_1_1 = new CNS11643_1992(5, 1, 1);
		final TRONCode c_5_1_1_tc = converter.to_tc(c_5_1_1);
		final String c_5_1_1_tc_s = c_5_1_1_tc.toString();
		assertEquals("6-9880", c_5_1_1_tc_s);

		final CNS11643_1992 c_5_94_94 = new CNS11643_1992(5, 94, 94);
		final TRONCode c_5_94_94_tc = converter.to_tc(c_5_94_94);
		final String c_5_94_94_tc_s = c_5_94_94_tc.toString();
		assertEquals("6-DE8F", c_5_94_94_tc_s);

		final CNS11643_1992 c_6_1_1 = new CNS11643_1992(6, 1, 1);
		final TRONCode c_6_1_1_tc = converter.to_tc(c_6_1_1);
		final String c_6_1_1_tc_s = c_6_1_1_tc.toString();
		assertEquals("7-2121", c_6_1_1_tc_s);

		final CNS11643_1992 c_6_94_94 = new CNS11643_1992(6, 94, 94);
		final TRONCode c_6_94_94_tc = converter.to_tc(c_6_94_94);
		final String c_6_94_94_tc_s = c_6_94_94_tc.toString();
		assertEquals("7-7E7E", c_6_94_94_tc_s);

		final CNS11643_1992 c_7_1_1 = new CNS11643_1992(7, 1, 1);
		final TRONCode c_7_1_1_tc = converter.to_tc(c_7_1_1);
		final String c_7_1_1_tc_s = c_7_1_1_tc.toString();
		assertEquals("7-8021", c_7_1_1_tc_s);

		final CNS11643_1992 c_7_94_94 = new CNS11643_1992(7, 94, 94);
		final TRONCode c_7_94_94_tc = converter.to_tc(c_7_94_94);
		final String c_7_94_94_tc_s = c_7_94_94_tc.toString();
		assertEquals("7-DD7E", c_7_94_94_tc_s);
	}

	public void testUnicode() {
		final Converter converter = new Converter();

		final Unicode_2 u_0 = new Unicode_2(0);
		final TRONCode u_0_tc = converter.to_tc(u_0);
		final String u_0_tc_s = u_0_tc.toString();
		assertEquals("16-2121", u_0_tc_s);

		final Unicode_2 u_1 = new Unicode_2(1);
		final TRONCode u_1_tc = converter.to_tc(u_1);
		final String u_1_tc_s = u_1_tc.toString();
		assertEquals("16-2122", u_1_tc_s);

		final Unicode_2 u_2283 = new Unicode_2(0x2283);
		final TRONCode u_2283_tc = converter.to_tc(u_2283);
		final String u_2283_tc_s = u_2283_tc.toString();
		assertEquals("16-7E7E", u_2283_tc_s);

		final Unicode_2 u_2284 = new Unicode_2(0x2284);
		final TRONCode u_2284_tc = converter.to_tc(u_2284);
		final String u_2284_tc_s = u_2284_tc.toString();
		assertEquals("16-8021", u_2284_tc_s);

		final Unicode_2 u_4dff = new Unicode_2(0x4dff);
		final TRONCode u_4dff_tc = converter.to_tc(u_4dff);
		final String u_4dff_tc_s = u_4dff_tc.toString();
		assertEquals("16-F648", u_4dff_tc_s);

		final Unicode_2 u_9fa6 = new Unicode_2(0x9fa6);
		final TRONCode u_9fa6_tc = converter.to_tc(u_9fa6);
		final String u_9fa6_tc_s = u_9fa6_tc.toString();
		assertEquals("16-C29E", u_9fa6_tc_s);

		final Unicode_2 u_abff = new Unicode_2(0xabff);
		final TRONCode u_abff_tc = converter.to_tc(u_abff);
		final String u_abff_tc_s = u_abff_tc.toString();
		assertEquals("16-DBA9", u_abff_tc_s);

		final Unicode_2 u_ac00 = new Unicode_2(0xac00);
		final TRONCode u_ac00_tc = converter.to_tc(u_ac00);
		final String u_ac00_tc_s = u_ac00_tc.toString();
		assertEquals("17-2121", u_ac00_tc_s);

		final Unicode_2 u_ce83 = new Unicode_2(0xce83);
		final TRONCode u_ce83_tc = converter.to_tc(u_ce83);
		final String u_ce83_tc_s = u_ce83_tc.toString();
		assertEquals("17-7E7E", u_ce83_tc_s);

		final Unicode_2 u_ce84 = new Unicode_2(0xce84);
		final TRONCode u_ce84_tc = converter.to_tc(u_ce84);
		final String u_ce84_tc_s = u_ce84_tc.toString();
		assertEquals("17-8021", u_ce84_tc_s);

		final Unicode_2 u_f8ff = new Unicode_2(0xf8ff);
		final TRONCode u_f8ff_tc = converter.to_tc(u_f8ff);
		final String u_f8ff_tc_s = u_f8ff_tc.toString();
		assertEquals("17-F362", u_f8ff_tc_s);

		final Unicode_2 u_fa2e = new Unicode_2(0xfa2e);
		final TRONCode u_fa2e_tc = converter.to_tc(u_fa2e);
		final String u_fa2e_tc_s = u_fa2e_tc.toString();
		assertEquals("17-F677", u_fa2e_tc_s);

		final Unicode_2 u_fcc7 = new Unicode_2(0xfcc7);
		final TRONCode u_fcc7_tc = converter.to_tc(u_fcc7);
		final String u_fcc7_tc_s = u_fcc7_tc.toString();
		assertEquals("17-FD7E", u_fcc7_tc_s);

		final Unicode_2 u_fcc8 = new Unicode_2(0xfcc8);
		final TRONCode u_fcc8_tc = converter.to_tc(u_fcc8);
		final String u_fcc8_tc_s = u_fcc8_tc.toString();
		assertEquals("17-2180", u_fcc8_tc_s);

		final Unicode_2 u_ffff = new Unicode_2(0xffff);
		final TRONCode u_ffff_tc = converter.to_tc(u_ffff);
		final String u_ffff_tc_s = u_ffff_tc.toString();
		assertEquals("17-27C3", u_ffff_tc_s);
	}
}
